@@ -130,7 +130,10 @@ rescale.numeric <- function(x,
   attr(out, "new_max") <- new_max
   attr(out, "range_difference") <- max_value - min_value
   attr(out, "to_range") <- c(new_min, new_max)
-  class(out) <- c("dw_transformer", class(out))
+  # don't add attribute when we call data frame methods
+  if (!isFALSE(dot_args$add_transform_class)) {
+    class(out) <- c("dw_transformer", class(out))
+  }
 
   out
 }
@@ -142,6 +145,7 @@ rescale.grouped_df <- function(x,
                                exclude = NULL,
                                to = c(0, 100),
                                range = NULL,
+                               append = FALSE,
                                ignore_case = FALSE,
                                regex = FALSE,
                                verbose = FALSE,
@@ -157,9 +161,26 @@ rescale.grouped_df <- function(x,
     exclude,
     ignore_case,
     regex = regex,
+    remove_group_var = TRUE,
     verbose = verbose
   )
 
+  # when we append variables, we call ".process_append()", which will
+  # create the new variables and updates "select", so new variables are processed
+  if (!isFALSE(append)) {
+    # process arguments
+    args <- .process_append(
+      x,
+      select,
+      append,
+      append_suffix = "_r",
+      preserve_value_labels = TRUE
+    )
+    # update processed arguments
+    x <- args$x
+    select <- args$select
+  }
+
   x <- as.data.frame(x)
   for (rows in grps) {
     x[rows, ] <- rescale(
@@ -168,11 +189,13 @@ rescale.grouped_df <- function(x,
       exclude = exclude,
       to = to,
       range = range,
+      append = FALSE, # need to set to FALSE here, else variable will be doubled
+      add_transform_class = FALSE,
       ...
     )
   }
   # set back class, so data frame still works with dplyr
-  attributes(x) <- info
+  attributes(x) <- utils::modifyList(info, attributes(x))
   x
 }
 
@@ -185,6 +208,7 @@ rescale.data.frame <- function(x,
                                exclude = NULL,
                                to = c(0, 100),
                                range = NULL,
+                               append = FALSE,
                                ignore_case = FALSE,
                                regex = FALSE,
                                verbose = FALSE,
@@ -198,6 +222,21 @@ rescale.data.frame <- function(x,
     verbose = verbose
   )
 
+  # when we append variables, we call ".process_append()", which will
+  # create the new variables and updates "select", so new variables are processed
+  if (!isFALSE(append)) {
+    # process arguments
+    args <- .process_append(
+      x,
+      select,
+      append,
+      append_suffix = "_r"
+    )
+    # update processed arguments
+    x <- args$x
+    select <- args$select
+  }
+
   # Transform the range so that it is a list now
   if (!is.null(range) && !is.list(range)) {
     range <- stats::setNames(rep(list(range), length(select)), select)
@@ -208,7 +247,7 @@ rescale.data.frame <- function(x,
   }
 
   x[select] <- as.data.frame(sapply(select, function(n) {
-    rescale(x[[n]], to = to[[n]], range = range[[n]])
+    rescale(x[[n]], to = to[[n]], range = range[[n]], add_transform_class = FALSE)
   }, simplify = FALSE))
   x
 }
