@@ -94,9 +94,9 @@ data_tabulate.default <- function(x, drop_levels = FALSE, name = NULL, verbose =
     } else {
       var_info <- data.frame(
         Variable = obj_name,
-        Group = paste0(lapply(colnames(group_variable), function(i) {
+        Group = toString(lapply(colnames(group_variable), function(i) {
           sprintf("%s (%s)", i, group_variable[[i]])
-        }), collapse = ", "),
+        })),
         stringsAsFactors = FALSE
       )
     }
@@ -232,16 +232,23 @@ format.dw_data_tabulate <- function(x, format = "text", big_mark = NULL, ...) {
   ftab$N <- gsub("\\.00$", "", ftab$N)
 
   # insert big marks?
-  if (is.null(big_mark) && any(nchar(ftab$N) > 5)) {
-    big_mark <- ","
-  }
-  if (!is.null(big_mark)) {
-    ftab$N <- prettyNum(ftab$N, big.mark = big_mark)
-  }
+  ftab$N <- .add_commas_in_numbers(ftab$N, big_mark)
 
   ftab
 }
 
+.add_commas_in_numbers <- function(x, big_mark = NULL) {
+  if (is.null(big_mark) && any(nchar(x) > 5)) {
+    big_mark <- ","
+  }
+  if (!is.null(big_mark)) {
+    x <- prettyNum(x, big.mark = big_mark)
+  }
+
+  x
+}
+
+
 
 #' @export
 print.dw_data_tabulate <- function(x, big_mark = NULL, ...) {
@@ -252,15 +259,18 @@ print.dw_data_tabulate <- function(x, big_mark = NULL, ...) {
 
   # grouped data? if yes, add information on grouping factor
   if (!is.null(a$group_variable)) {
-    group_title <- paste0("Grouped by ", paste0(lapply(colnames(a$group_variable), function(i) {
+    group_title <- paste0("Grouped by ", toString(lapply(colnames(a$group_variable), function(i) {
       sprintf("%s (%s)", i, a$group_variable[[i]])
-    }), collapse = ", "))
+    })))
     cat(insight::print_color(group_title, "blue"))
     cat("\n")
   }
 
+  a$total_n <- .add_commas_in_numbers(a$total_n, big_mark)
+  a$valid_n <- .add_commas_in_numbers(a$valid_n, big_mark)
+
   # summary of total and valid N (we may add mean/sd as well?)
-  summary_line <- sprintf("# total N=%i valid N=%i\n\n", a$total_n, a$valid_n)
+  summary_line <- sprintf("# total N=%s valid N=%s\n\n", a$total_n, a$valid_n)
   cat(insight::print_color(summary_line, "blue"))
 
   # remove information that goes into the header/footer
@@ -486,6 +496,7 @@ print_md.dw_data_tabulates <- function(x, big_mark = NULL, ...) {
     "chr" = "character",
     "lbl" = "labelled",
     "cpl" = "complex",
+    "lgl" = "logical",
     vt
   )
 }
