@@ -1,7 +1,6 @@
 #' Compute Skewness and (Excess) Kurtosis
 #'
 #' @param x A numeric vector or data.frame.
-#' @param na.rm Remove missing values.
 #' @param type Type of algorithm for computing skewness. May be one of `1`
 #'   (or `"1"`, `"I"` or `"classic"`), `2` (or `"2"`,
 #'   `"II"` or `"SPSS"` or `"SAS"`) or `3` (or  `"3"`,
@@ -14,6 +13,7 @@
 #' @param object An object returned by `skewness()` or `kurtosis()`.
 #' @param verbose Toggle warnings and messages.
 #' @param ... Arguments passed to or from other methods.
+#' @inheritParams coef_var
 #'
 #' @details
 #'
@@ -95,12 +95,7 @@
 #' skewness(rnorm(1000))
 #' kurtosis(rnorm(1000))
 #' @export
-skewness <- function(x,
-                     na.rm = TRUE,
-                     type = "2",
-                     iterations = NULL,
-                     verbose = TRUE,
-                     ...) {
+skewness <- function(x, ...) {
   UseMethod("skewness")
 }
 
@@ -108,14 +103,22 @@ skewness <- function(x,
 # skewness -----------------------------------------
 
 
+#' @rdname skewness
 #' @export
 skewness.numeric <- function(x,
-                             na.rm = TRUE,
+                             remove_na = TRUE,
                              type = "2",
                              iterations = NULL,
                              verbose = TRUE,
+                             na.rm = TRUE,
                              ...) {
-  if (na.rm) x <- x[!is.na(x)]
+  # TODO: remove deprecated argument later
+  if (!missing(na.rm)) {
+    # TODO: add deprecation warning in a later update
+    remove_na <- na.rm
+  }
+
+  if (remove_na) x <- x[!is.na(x)]
   n <- length(x)
   out <- (sum((x - mean(x))^3) / n) / (sum((x - mean(x))^2) / n)^1.5
 
@@ -152,7 +155,7 @@ skewness.numeric <- function(x,
         data = x,
         statistic = .boot_skewness,
         R = iterations,
-        na.rm = na.rm,
+        remove_na = remove_na,
         type = type
       )
       out_se <- stats::sd(results$t, na.rm = TRUE)
@@ -168,18 +171,24 @@ skewness.numeric <- function(x,
 }
 
 
-
 #' @export
 skewness.matrix <- function(x,
-                            na.rm = TRUE,
+                            remove_na = TRUE,
                             type = "2",
                             iterations = NULL,
+                            na.rm = TRUE,
                             ...) {
+  # TODO: remove deprecated argument later
+  if (!missing(na.rm)) {
+    # TODO: add deprecation warning in a later update
+    remove_na <- na.rm
+  }
+
   .skewness <- apply(
     x,
     2,
     skewness,
-    na.rm = na.rm,
+    remove_na = remove_na,
     type = type,
     iterations = iterations
   )
@@ -197,16 +206,22 @@ skewness.matrix <- function(x,
 }
 
 
-
 #' @export
 skewness.data.frame <- function(x,
-                                na.rm = TRUE,
+                                remove_na = TRUE,
                                 type = "2",
                                 iterations = NULL,
+                                na.rm = TRUE,
                                 ...) {
+  # TODO: remove deprecated argument later
+  if (!missing(na.rm)) {
+    # TODO: add deprecation warning in a later update
+    remove_na <- na.rm
+  }
+
   .skewness <- lapply(x,
     skewness,
-    na.rm = na.rm,
+    remove_na = remove_na,
     type = type,
     iterations = iterations
   )
@@ -218,16 +233,22 @@ skewness.data.frame <- function(x,
 }
 
 
-
 #' @export
 skewness.default <- function(x,
-                             na.rm = TRUE,
+                             remove_na = TRUE,
                              type = "2",
                              iterations = NULL,
+                             na.rm = TRUE,
                              ...) {
+  # TODO: remove deprecated argument later
+  if (!missing(na.rm)) {
+    # TODO: add deprecation warning in a later update
+    remove_na <- na.rm
+  }
+
   skewness(
     .factor_to_numeric(x),
-    na.rm = na.rm,
+    remove_na = remove_na,
     type = type,
     iterations = iterations
   )
@@ -240,24 +261,27 @@ skewness.default <- function(x,
 
 #' @rdname skewness
 #' @export
-kurtosis <- function(x,
-                     na.rm = TRUE,
-                     type = "2",
-                     iterations = NULL,
-                     verbose = TRUE,
-                     ...) {
+kurtosis <- function(x, ...) {
   UseMethod("kurtosis")
 }
 
 
+#' @rdname skewness
 #' @export
 kurtosis.numeric <- function(x,
-                             na.rm = TRUE,
+                             remove_na = TRUE,
                              type = "2",
                              iterations = NULL,
                              verbose = TRUE,
+                             na.rm = TRUE,
                              ...) {
-  if (na.rm) x <- x[!is.na(x)]
+  # TODO: remove deprecated argument later
+  if (!missing(na.rm)) {
+    # TODO: add deprecation warning in a later update
+    remove_na <- na.rm
+  }
+
+  if (remove_na) x <- x[!is.na(x)]
   n <- length(x)
   out <- n * sum((x - mean(x))^4) / (sum((x - mean(x))^2)^2)
 
@@ -293,7 +317,7 @@ kurtosis.numeric <- function(x,
       data = x,
       statistic = .boot_kurtosis,
       R = iterations,
-      na.rm = na.rm,
+      remove_na = remove_na,
       type = type
     )
     out_se <- stats::sd(results$t, na.rm = TRUE)
@@ -310,15 +334,22 @@ kurtosis.numeric <- function(x,
 
 #' @export
 kurtosis.matrix <- function(x,
-                            na.rm = TRUE,
+                            remove_na = TRUE,
                             type = "2",
                             iterations = NULL,
+                            na.rm = TRUE,
                             ...) {
+  # TODO: remove deprecated argument later
+  if (!missing(na.rm)) {
+    # TODO: add deprecation warning in a later update
+    remove_na <- na.rm
+  }
+
   .kurtosis <- apply(
     x,
     2,
     kurtosis,
-    na.rm = na.rm,
+    remove_na = remove_na,
     type = type,
     iterations = iterations
   )
@@ -332,16 +363,22 @@ kurtosis.matrix <- function(x,
 }
 
 
-
 #' @export
 kurtosis.data.frame <- function(x,
-                                na.rm = TRUE,
+                                remove_na = TRUE,
                                 type = "2",
                                 iterations = NULL,
+                                na.rm = TRUE,
                                 ...) {
+  # TODO: remove deprecated argument later
+  if (!missing(na.rm)) {
+    # TODO: add deprecation warning in a later update
+    remove_na <- na.rm
+  }
+
   .kurtosis <- lapply(x,
     kurtosis,
-    na.rm = na.rm,
+    remove_na = remove_na,
     type = type,
     iterations = iterations
   )
@@ -351,16 +388,22 @@ kurtosis.data.frame <- function(x,
 }
 
 
-
 #' @export
 kurtosis.default <- function(x,
-                             na.rm = TRUE,
+                             remove_na = TRUE,
                              type = "2",
                              iterations = NULL,
+                             na.rm = TRUE,
                              ...) {
+  # TODO: remove deprecated argument later
+  if (!missing(na.rm)) {
+    # TODO: add deprecation warning in a later update
+    remove_na <- na.rm
+  }
+
   kurtosis(
     .factor_to_numeric(x),
-    na.rm = na.rm,
+    remove_na = remove_na,
     type = type,
     iterations = iterations
   )
@@ -422,13 +465,11 @@ summary.parameters_kurtosis <- function(object, test = FALSE, ...) {
 .check_skewness_type <- function(type) {
   # convenience
   if (is.numeric(type)) type <- as.character(type)
+  skewness_types <- c("1", "2", "3", "I", "II", "III", "classic", "SPSS", "SAS", "Minitab")
+  is_skewness_type_invalid <- is.null(type) || is.na(type) || !(type %in% skewness_types)
 
-  if (is.null(type) ||
-    is.na(type) ||
-    !(type %in% c("1", "2", "3", "I", "II", "III", "classic", "SPSS", "SAS", "Minitab"))) {
-    insight::format_warning(
-      "'type' must be a character value from \"1\" to \"3\". Using 'type=\"2\"' now."
-    )
+  if (is_skewness_type_invalid) {
+    insight::format_warning("'type' must be a character value from \"1\" to \"3\". Using 'type=\"2\"' now.")
     type <- "2"
   }
 
@@ -450,18 +491,18 @@ summary.parameters_kurtosis <- function(object, test = FALSE, ...) {
 
 # bootstrapping -----------------------------------
 
-.boot_skewness <- function(data, indices, na.rm, type) {
+.boot_skewness <- function(data, indices, remove_na, type) {
   datawizard::skewness(data[indices],
-    na.rm = na.rm,
+    remove_na = remove_na,
     type = type,
     iterations = NULL
   )$Skewness
 }
 
 
-.boot_kurtosis <- function(data, indices, na.rm, type) {
+.boot_kurtosis <- function(data, indices, remove_na, type) {
   datawizard::kurtosis(data[indices],
-    na.rm = na.rm,
+    remove_na = remove_na,
     type = type,
     iterations = NULL
   )$Kurtosis
