@@ -16,27 +16,38 @@ test_that("unnormalize error if not supported", {
 })
 
 test_that("unnormalize and unstandardized x 4", {
+  set.seed(123)
   x <- rnorm(6, 4, 10)
 
   z <- standardise(x)
-  # attributes(z)
+  expect_named(attributes(z), c("center", "scale", "robust", "class"))
+  expect_equal(attributes(z)$center, 8.47, tolerance = 0.01)
   expect_equal(unstandardise(z), x, ignore_attr = TRUE)
 
   z <- center(x)
-  # attributes(z)
+  expect_named(attributes(z), c("center", "scale", "robust", "class"))
   expect_equal(unstandardise(z), x, ignore_attr = TRUE)
 
 
   z <- normalize(x)
-  # attributes(z)
+  expect_named(attributes(z), c(
+    "include_bounds", "flag_bounds", "min_value",
+    "vector_length", "range_difference", "class"
+  ))
   expect_equal(unnormalize(z), x, ignore_attr = TRUE)
 
   z <- change_scale(x, to = c(-3, 14.5))
-  # attributes(z)
+  expect_named(attributes(z), c(
+    "min_value", "max_value", "new_min", "new_max",
+    "range_difference", "to_range", "class"
+  ))
   expect_equal(unnormalize(z), x, ignore_attr = TRUE)
 
   z <- change_scale(x, range = c(-100, 100))
-  # attributes(z)
+  expect_named(attributes(z), c(
+    "min_value", "max_value", "new_min", "new_max",
+    "range_difference", "to_range", "class"
+  ))
   expect_equal(unnormalize(z), x, ignore_attr = TRUE)
 })
 
